@@ -14,6 +14,8 @@ https://github.com/marcelcaraciolo/foursquare
 
 """
 
+from utils import parse_datetime
+
 
 class ResultSet(list):
     """A list like object that holds results from a Twitter API query."""
@@ -126,6 +128,37 @@ class Venue(Model):
         return self.name.encode('utf-8')
 
 
+class Checkin(Model):
+    @classmethod
+    def parse(cls, api, json):
+        checkin = cls(api)
+        for key, value in json.items():
+            if key == 'venue':
+                setattr(checkin, key, Venue.parse(api, value))
+            elif key == 'createdAt':
+                setattr(checkin, key, parse_datetime(value))
+            else:
+                setattr(checkin, key, value)
+
+        return checkin
+
+    def __repr__(self):
+        return self.venue.name.encode('utf-8') + ' - ' + self.createdAt.strftime('%d/%m/%Y %H:%M:%S')
+
+
+class Score(Model):
+    @classmethod
+    def parse(cls, api, json):
+        scores = cls(api)
+        for key, value in json.items():
+            setattr(scores, key, value)
+
+        return scores
+
+    def __repr__(self):
+        return 'scores'
+
+
 class User(Model):
     @classmethod
     def parse(cls, api, json):
@@ -140,12 +173,33 @@ class User(Model):
                 except ValueError:
                     city = value.split(',')
                 setattr(user, 'city', city)
+
+            elif key == 'friends':
+                pass
+                #we will use api for this
+
+            elif key == 'checkins':
+                pass
+                #we will use api for this
+
+            elif key == 'scores':
+                setattr(user, key, Score.parse(api, value))
+            elif key in ['following', 'todos', 'badges', 'requests', 'photos', 'tips']:
+                setattr(user, key, value['count'])
             else:
                 setattr(user, key, value)
+
         return user
 
+    def checkins(self, **kwargs):
+        return self._api.user_checkins(id=self.id, **kwargs)
+
+    def friends(self, **kwargs):
+        return self._api.user_friends(id=self.id, **kwargs)
+
     def __repr__(self):
-        return self.name
+        return self.name.encode('utf-8') if hasattr(self, 'name') \
+            else self.firstName.encode('utf-8')
 
 
 class Tip(Model):
@@ -172,6 +226,12 @@ class SearchResult(Model):
         return Venue.parse(api, json)
 
 
+class FriendsResult(Model):
+    @classmethod
+    def parse(cls, api, json):
+        return User.parse(api, json)
+
+
 class ModelFactory(object):
     """
     Used by parsers for creating instances
@@ -183,3 +243,5 @@ class ModelFactory(object):
     tips = Tip
     user = User
     venues = SearchResult
+    friends = FriendsResult
+    checkins = Checkin
